Crate wallet_gen [−] [src]
A Rust library to generate various cryptocurrency wallets.
Enable the serde feature to add #[derive(Serialize, Deserialize)]
to structures and naming to Coin.
Modules
| bitcoin |
Various functions related to Bitcoin wallet generation and validation. |
| coin |
Represents the various cryptocurrencies supported by this crate. |
| cryptonote |
Various functions related to Cryptonote (e.g. Monero) wallet generation and validation. |
| ed25519 |
Modified ed25519 cryptography for use by Cryptonote. Specifically, public-key calculation is performed using scalar multiplication without using SHA512 at all. |
| error |
Error type for the crate. |
| ethereum |
Various functions related to Ethereum wallet generation and validation. |
| hex_slice |
Helper struct to easily create hex bytestrings from byte slices. |
| prelude |
"Prelude" module, to re-export various commonly used symbols.
Add |
| wallet |
A representation of a cryptocurrency wallet. Stores in that coin's native WIF, or "wallet import format". |