BitcoinWifData

Struct BitcoinWifData 

pub struct BitcoinWifData(/* private fields */);
Constants for generating addresses and private keys in Bitcoin-based coins, when converting to Wallet Import Format (WIF).

Implementations

Source

impl BitcoinWifData

pub fn network_version(self) -> &'static [u8]

Gets the network version used in WIF conversion.

pub fn private_key_prefix(self) -> u8

Gets the prefix to prepend when creating the WIF private key.

pub fn wif_start(self) -> &'static str

Returns the WIF character set for the beginning of the string.

pub fn cwif_start(self) -> &'static str

Returns the CWIF character set for the beginning of the string.

pub fn check_wif(self, s: &str) -> bool

See if the given string matches the character set returned by wif_start().

pub fn check_cwif(self, s: &str) -> bool

See if the given string matches the character set returned by cwif_start().