pub struct PrivateKey(/* private fields */);Expand description
An ed25519 private key.
Implementations
Sourceimpl PrivateKey
impl PrivateKey
Sourcepub fn from_bytes(bytes: [u8; 32], ctx: &mut BigNumContextRef) -> Result<Self>
pub fn from_bytes(bytes: [u8; 32], ctx: &mut BigNumContextRef) -> Result<Self>
Generate a private key from the given seed. The byte data will be converted to a valid private ed25519 key.
Sourcepub fn into_bytes(self) -> [u8; 32]
pub fn into_bytes(self) -> [u8; 32]
Converts this private key into an array of its bytes