pub struct BitcoinWifData(/* private fields */);Expand description
Constants for generating addresses and private keys in Bitcoin-based coins, when converting to Wallet Import Format (WIF).
Implementations
Sourceimpl BitcoinWifData
impl BitcoinWifData
Sourcepub fn network_version(self) -> &'static [u8] ⓘ
pub fn network_version(self) -> &'static [u8] ⓘ
Gets the network version used in WIF conversion.
Sourcepub fn private_key_prefix(self) -> u8
pub fn private_key_prefix(self) -> u8
Gets the prefix to prepend when creating the WIF private key.
Sourcepub fn wif_start(self) -> &'static str
pub fn wif_start(self) -> &'static str
Returns the WIF character set for the beginning of the string.
Sourcepub fn cwif_start(self) -> &'static str
pub fn cwif_start(self) -> &'static str
Returns the CWIF character set for the beginning of the string.
Sourcepub fn check_wif(self, s: &str) -> bool
pub fn check_wif(self, s: &str) -> bool
See if the given string matches the character set returned by wif_start().
Sourcepub fn check_cwif(self, s: &str) -> bool
pub fn check_cwif(self, s: &str) -> bool
See if the given string matches the character set returned by cwif_start().